NAME = 'OnTV'
VERSION = '2.4.0'
SERVERS_DIR = '/usr/local/lib/bonobo/servers'
DATA_DIR = '/usr/local/share/ontv'
IMAGES_DIR = '/usr/local/share/ontv/images'
UI_DIR = '/usr/local/share/gnome-2.0/ui'
LOCALE_DIR = '/usr/local/share/locale'
